Title: [210460] trunk/Source/WebInspectorUI
Revision
210460
Author
[email protected]
Date
2017-01-06 16:34:38 -0800 (Fri, 06 Jan 2017)

Log Message

Unreviewed, rolling out r210110.
https://bugs.webkit.org/show_bug.cgi?id=166783

Introduced a regression commenting out individual properties
(Requested by JoePeck on #webkit).

Reverted changeset:

"Web Inspector: Styles sidebar: Uncommenting CSS rules of
pseudo-elements doesn't work"
https://bugs.webkit.org/show_bug.cgi?id=165831
http://trac.webkit.org/changeset/210110

Modified Paths

Diff

Modified: trunk/Source/WebInspectorUI/ChangeLog (210459 => 210460)


--- trunk/Source/WebInspectorUI/ChangeLog	2017-01-06 23:38:32 UTC (rev 210459)
+++ trunk/Source/WebInspectorUI/ChangeLog	2017-01-07 00:34:38 UTC (rev 210460)
@@ -1,3 +1,18 @@
+2017-01-06  Commit Queue  <[email protected]>
+
+        Unreviewed, rolling out r210110.
+        https://bugs.webkit.org/show_bug.cgi?id=166783
+
+        Introduced a regression commenting out individual properties
+        (Requested by JoePeck on #webkit).
+
+        Reverted changeset:
+
+        "Web Inspector: Styles sidebar: Uncommenting CSS rules of
+        pseudo-elements doesn't work"
+        https://bugs.webkit.org/show_bug.cgi?id=165831
+        http://trac.webkit.org/changeset/210110
+
 2017-01-05  Joseph Pecoraro  <[email protected]>
 
         Web Inspector: Remove unused delegate from VisualStyleSelectorSection

Modified: trunk/Source/WebInspectorUI/UserInterface/Views/CSSStyleDeclarationTextEditor.js (210459 => 210460)


--- trunk/Source/WebInspectorUI/UserInterface/Views/CSSStyleDeclarationTextEditor.js	2017-01-06 23:38:32 UTC (rev 210459)
+++ trunk/Source/WebInspectorUI/UserInterface/Views/CSSStyleDeclarationTextEditor.js	2017-01-07 00:34:38 UTC (rev 210460)
@@ -309,11 +309,13 @@
             if (!properties.length)
                 return false;
 
-            this._resetContent();
+            for (var property of properties) {
+                if (property._commentRange) {
+                    this._uncommentRange(property._commentRange);
+                    property._commentRange = null;
+                }
+            }
 
-            for (let property of properties)
-                this._uncommentProperty(property);
-
             return true;
         }
 
@@ -1270,6 +1272,9 @@
         if (!range)
             return;
 
+        property._commentRange = range;
+        property._commentRange.to.ch += 6; // Number of characters added by comments.
+
         var text = this._codeMirror.getRange(range.from, range.to);
 
         function update()
@@ -1286,19 +1291,14 @@
 
     _propertyCommentCheckboxChanged(event)
     {
-        this._uncommentProperty(event.target);
-    }
-
-    _uncommentProperty(property)
-    {
-        let textMarker = property.__propertyTextMarker;
-        console.assert(textMarker);
-        if (!textMarker)
+        var commentTextMarker = event.target.__commentTextMarker;
+        console.assert(commentTextMarker);
+        if (!commentTextMarker)
             return;
 
-        // Check if the property has been removed already, like from double-clicking
-        // the checkbox and calling this event listener multiple times.
-        let range = textMarker.find();
+        // Check if the comment has been removed already, like from double-clicking
+        // the checkbox and calling event listener multiple times.
+        var range = commentTextMarker.find();
         if (!range)
             return;
 
_______________________________________________
webkit-changes mailing list
[email protected]
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to